@@ -8,7 +8,6 @@ import hashlib
 import json
 import os
 import platform as _platform
-import shlex
 import subprocess
 import sys
 import time
@@ -458,6 +457,8 @@ def run_dvc_repro(
     objects = []
     with open("dvc.yaml") as f:
         pipeline = calkit.ryaml.load(f)
+        if pipeline is None:
+            raise_error("Pipeline is empty")
         for stage_name, stage_info in pipeline.get("stages", {}).items():
             ckmeta = stage_info.get("meta", {}).get("calkit")
             if ckmeta is not None:
@@ -840,11 +841,14 @@ def check_docker_env(
             "Layers"
         ] or dockerfile_md5 != lock[0].get("DockerfileMD5")
     if rebuild:
-        cmd = ["docker", "build", "-t", tag, "-f", fpath]
+        wdir, fname = os.path.split(fpath)
+        if not wdir:
+            wdir = None
+        cmd = ["docker", "build", "-t", tag, "-f", fname]
         if platform is not None:
             cmd += ["--platform", platform]
         cmd.append(".")
-        subprocess.check_call(cmd)
+        subprocess.check_call(cmd, cwd=wdir)
     # Write the lock file
     inspect = get_docker_inspect()
     inspect[0]["DockerfileMD5"] = dockerfile_md5
